Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(620)

Unified Diff: net/ssl/client_cert_store.h

Issue 2848313003: Revert of Remove client_certs from SSLCertRequestInfo. (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/socket/socket_test_util.cc ('k') | net/ssl/client_cert_store_mac.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/ssl/client_cert_store.h
diff --git a/net/ssl/client_cert_store.h b/net/ssl/client_cert_store.h
index b73d871e2de4f37b6b534d2e3347e10d63d11862..f87c22ee47fc07626c4502d67b9b80cf778deea1 100644
--- a/net/ssl/client_cert_store.h
+++ b/net/ssl/client_cert_store.h
@@ -22,16 +22,14 @@
public:
virtual ~ClientCertStore() {}
- using ClientCertListCallback = base::Callback<void(CertificateList)>;
-
// Get client certs matching the |cert_request_info|. On completion, the
// results will be stored in |selected_certs| and the |callback| will be run.
// The |callback| may be called sychronously. The caller must ensure the
// ClientCertStore and |cert_request_info| remain alive until the callback
// has been run.
virtual void GetClientCerts(const SSLCertRequestInfo& cert_request_info,
- const ClientCertListCallback& callback) = 0;
-
+ CertificateList* selected_certs,
+ const base::Closure& callback) = 0;
protected:
ClientCertStore() {}
« no previous file with comments | « net/socket/socket_test_util.cc ('k') | net/ssl/client_cert_store_mac.h » ('j') | no next file with comments »
@@ -22,16 +22,14 @@
// results will be stored in |selected_certs| and the |callback| will be run.
// The |callback| may be called sychronously. The caller must ensure the
- // ClientCertStore and |cert_request_info| remain alive until the callback
- // has been run.
+ // ClientCertStore, |cert_request_info|, and |selected_certs| remain alive
+ // until the callback has been run.
virtual void GetClientCerts(const SSLCertRequestInfo& cert_request_info,

Powered by Google App Engine
This is Rietveld 408576698